{ pkgs, config, ... }:
{
  boot = {
    # nixos-hardware use latest kernel by default. It has been set a while ago, we maybe don't need it anymore?
    kernelPackages = pkgs.linuxPackages;

    # Otherwise it will not show stage1 echo and prompt
    # UPST
    kernelParams = ["console=tty0"];

    # Pinebook supports UEFI, at least when tow-boot is installed on the SPI
    loader = {
      # EFI Variables don't work (no generation appears in systemd-boot)
      efi.canTouchEfiVariables = false;

      # systemd-boot crashes after booting, so GRUB it is
      grub = {
        enable = true;
        efiSupport = true;
        efiInstallAsRemovable = true;
        device = "nodev";
      };
    };
  };

  zramSwap = { # Not capable of building itself otherwise
    enable = true;
    memoryPercent = 150; # Factory settings
  };

  # Fixes black font on Alacritty
  environment.variables.PAN_MESA_DEBUG = "gl3";
}
